/*--------------------------------------------------------------------*\
  File:      ThruputAddOn.h
  Creator:   Matt Bogosian <mbogosian@usa.net>
  Copyright: (c)1998, Matt Bogosian. All rights reserved.
  Description: Header file describing the ThruputAddOn class.
  ID:        $Id: ThruputAddOn.h,v 1.1 1998/07/03 12:51:26 mattb Exp $
  Conventions:
      #defines - all uppercase letters with words separated by
          underscores.
          (E.G., #define MY_DEFINE 16).
      New data types (classes, structs, typedefs, etc.) - begin with
          an uppercase letter followed by lowercase words separated by
          uppercase letters.
          (E.G., typedef int MyTypedef;).
      Global constants (declared with const) - begin with "k_"
          followed by lowercase words separated by underscores.
          (E.G., const int k_my_constant(16);).
      Global variables - begin with "g_" followed by lowercase words
          separated by underscores.
          (E.G., int g_my_global;).
      Local variables - begin with a lowercase letter followed by
          lowercase words separated by underscores.
          (E.G., int my_local;).
      Argument variables - begin with "a_" followed by lowercase words
          separated by underscores.
          (E.G., ..., int a_my_argument, ...).
      Functions - begin with a lowercase letter followed by lowercase
          words separated by uppercase letters.
          (E.G., void myFunction(void);).
      Static member constants (declared with const) - begin with "mk_"
          followed by lowercase words separated by underscores.
          (E.G., static const int MyClass::mk_my_constant(16);).
      Static member variables - begin with "mg_" followed by lowercase
          words separated by underscores.
          (E.G., static int MyClass::mg_my_global(16);).
      Member variables - begin with "m_" followed by lowercase words
          separated by underscores.
          (E.G., int m_my_member;).
      Member Functions - begin with an uppercase letter followed by
          lowercase words separated by uppercase letters.
          (E.G., void MyClass::MyFunction(void);).
\*--------------------------------------------------------------------*/


/*--------------------------------------------------------------------*\
  =-=-=-=-=-=-=-=-=-=-=-=-=- Included Files -=-=-=-=-=-=-=-=-=-=-=-=-=
\*--------------------------------------------------------------------*/

#include "AddOn.h"


#ifndef THRUPUT_ADD_ON_H
#define THRUPUT_ADD_ON_H


/*--------------------------------------------------------------------*\
  =-=-=-=-=-=-=-=-=-=-=-=-= Structs, Classes =-=-=-=-=-=-=-=-=-=-=-=-=
\*--------------------------------------------------------------------*/

/*--------------------------------------------------------------------*\
  Class name:       ThruputAddOn
  Inherits from:    public AddOn
  New data members: none
  Description: Class to implement a dev_server add-on.
\*--------------------------------------------------------------------*/

#ifndef ThruputAddOn_SUPER
#define ThruputAddOn_SUPER AddOn
#endif

class ThruputAddOn : public ThruputAddOn_SUPER
{
	public:
	
		// Public member functions
		
/*--------------------------------------------------------------------*\
  Function name: ThruputAddOn
  Member of:     public ThruputAddOn
  Defined in:    ThruputAddOn.cpp
  Arguments:     const void * const a_data - the necessary basic data
                     for the add-on (this is given as an argument to
                     the dvsrvrNewAddOn() hook function. You must pass
                     that argument straight to the constructor for the
                     add-on. Do not pass go. Do not collect $200. (Bad
                     things may happen if the add-on is robbed of this
                     data.)
                 status_t * const a_err - a placeholder for the error
                     encountered during construction (see below).
                     Default: NULL.
  Throws:        none
  Description: Default class constructor. You must check the value of
      a_err or the return value of Status() after invoking the
      constructor to see if the object is usable. See the Status()
      function (derived) for possible error values.
\*--------------------------------------------------------------------*/
		
		ThruputAddOn(const void * const a_data, status_t  * const a_err = NULL);
		
/*--------------------------------------------------------------------*\
  Function name: virtual ~ThruputAddOn
  Member of:     public ThruputAddOn
  Defined in:    ThruputAddOn.cpp
  Arguments:     none
  Throws:        none
  Description: Class destructor.
\*--------------------------------------------------------------------*/
		
		virtual ~ThruputAddOn(void);
		
/*--------------------------------------------------------------------*\
  Function name: virtual Start
  Member of:     public ThruputAddOn
  Defined in:    ThruputAddOn.cpp
  Arguments:     const port_id a_send - the port on which messages
                     should be sent (the receiving port sent by the
                     DevCnnctn object in the driver).
                 const port_id a_recv - the port on which messages
                     should be received (the sending port sent by the
                     DevCnnctn object in the driver).
  Returns:       status_t - the error code associated with the
                     operation (see below).
  Throws:        none
  Description: Derived hook function.
\*--------------------------------------------------------------------*/
		
		virtual status_t Start(const port_id a_send, const port_id a_recv);
};


#endif    // THRUPUT_ADD_ON_H
