/*--------------------------------------------------------------------*\
  File:      ThruputView.h
  Creator:   Matt Bogosian <mbogosian@usa.net>
  Copyright: (c)1997, 1998, Matt Bogosian. All rights reserved.
  Description: Header file describing the ThruputView class.
  ID:        $Id: ThruputView.h,v 1.8 1998/07/03 21:35:21 mattb Exp $
  Conventions:
      #defines - all uppercase letters with words separated by
          underscores.
          (E.G., #define MY_DEFINE 16).
      New data types (classes, structs, typedefs, etc.) - begin with
          an uppercase letter followed by lowercase words separated by
          uppercase letters.
          (E.G., typedef int MyTypedef;).
      Global constants (declared with const) - begin with "k_"
          followed by lowercase words separated by underscores.
          (E.G., const int k_my_constant(16);).
      Global variables - begin with "g_" followed by lowercase words
          separated by underscores.
          (E.G., int g_my_global;).
      Local variables - begin with a lowercase letter followed by
          lowercase words separated by underscores.
          (E.G., int my_local;).
      Argument variables - begin with "a_" followed by lowercase words
          separated by underscores.
          (E.G., ..., int a_my_argument, ...).
      Functions - begin with a lowercase letter followed by lowercase
          words separated by uppercase letters.
          (E.G., void myFunction(void);).
      Static member constants (declared with const) - begin with "mk_"
          followed by lowercase words separated by underscores.
          (E.G., static const int MyClass::mk_my_constant(16);).
      Static member variables - begin with "mg_" followed by lowercase
          words separated by underscores.
          (E.G., static int MyClass::mg_my_global(16);).
      Member variables - begin with "m_" followed by lowercase words
          separated by underscores.
          (E.G., int m_my_member;).
      Member Functions - begin with an uppercase letter followed by
          lowercase words separated by uppercase letters.
          (E.G., void MyClass::MyFunction(void);).
\*--------------------------------------------------------------------*/


/*--------------------------------------------------------------------*\
  =-=-=-=-=-=-=-=-=-=-=-=-=- Included Files -=-=-=-=-=-=-=-=-=-=-=-=-=
\*--------------------------------------------------------------------*/

#include <View.h>


#ifndef THRUPUT_VIEW_H
#define THRUPUT_VIEW_H


/*--------------------------------------------------------------------*\
  =-=-=-=-=-=-=-=-=-=-=-=-= Structs, Classes =-=-=-=-=-=-=-=-=-=-=-=-=
\*--------------------------------------------------------------------*/

class BMenu;
class BMenuField;
class BMenuItem;
class BStatusBar;

/*--------------------------------------------------------------------*\
  Class name:       ThruputView
  Inherits from:    public BView
  New data members: public static const uint32 mk_select_dev - the
                        message type to select the device.
                    public static const uint32 mk_new_scale - the
                        message type to select the bytes per second
                        scale.
                    public static const uint32 mk_update_bps - the
                        message type to update the thruput.
                    private static const float mk_border - the border
                        between sub-views.
                    private static const float mk_hght_spc - the
                        spacing between controls.
                    private static const float mk_bar_width - the side
                        bar width.
                    private static const float mk_field_width - the
                        field width.
                    private static const char * const mk_devs - the
                        name of the devices menu.
                    private static const char * const mk_bps - the
                        name of the bps menu.
                    private static const rgb_color mk_high - the high
                        color.
                    private static const rgb_color mk_light - the
                        light color.
                    private static const rgb_color mk_dark - the dark
                        color.
                    private status_t m_status - the status of the
                        object.
                    private port_id m_port - the port from which to
                        read the number of bits.
                    private BMenu *m_devs_menu - the device selection
                        menu.
                    private BMenuField *m_devs - the device menu
                        control.
                    private BMenu *m_bps_menu - the bps scale
                        selection menu.
                    private BMenuField *m_bps - the bps scale menu
                        control.
                    private BStatusBar *m_thrpt_read - the read
                        thruput status bar.
                    private BStatusBar *m_thrpt_write - the write
                        thruput status bar.
  Description: Class to implement a view in which an approximation of
      the instantaneous thruput to a selected device is constantly
      displayed.
\*--------------------------------------------------------------------*/

#ifndef ThruputView_SUPER
#define ThruputView_SUPER BView
#endif

class ThruputView : public ThruputView_SUPER
{
	public:
	
		// Public static const data members
		static const uint32 mk_select_dev;
		static const uint32 mk_new_scale;
		static const uint32 mk_update_bps;
		
		// Public member functions
		
/*--------------------------------------------------------------------*\
  Function name: ThruputView
  Member of:     public ThruputView
  Defined in:    ThruputView.cpp
  Arguments:     const BRect a_frame - the frame of the view.
                 const char * const a_name - the name of the view.
                 const port_id a_port - the port from which to read
                     the number of bits.
                 const char * const a_dev - the preferred device.
                     Default: NULL.
                 const size_t a_bps - the preferred scale. Default: 0.
                 status_t * const a_err - a placeholder for the error
                     encountered during construction (see below).
                     Default: NULL.
  Throws:        none
  Description: Class constructor. You must check the value of a_err or
      the return value of Status() after invoking the constructor to
      see if the object is usable. See the Status() function (below)
      for possible error values.
\*--------------------------------------------------------------------*/
		
		ThruputView(const BRect a_frame, const char * const a_name, const port_id a_port, const char * const a_dev = NULL, const size_t a_bps = 0, status_t * const a_err = NULL);
		
/*--------------------------------------------------------------------*\
  Function name: virtual ~ThruputView
  Member of:     public ThruputView
  Defined in:    ThruputView.cpp
  Arguments:     none
  Throws:        none
  Description: Class destructor.
\*--------------------------------------------------------------------*/
		
		virtual ~ThruputView(void);
		
/*--------------------------------------------------------------------*\
  Function name: virtual AttachedToWindow
  Member of:     public ThruputView
  Defined in:    ThruputView.cpp
  Arguments:     none
  Returns:       none
  Throws:        none
  Description: Derived hook function.
\*--------------------------------------------------------------------*/
		
		virtual void AttachedToWindow(void);
		
/*--------------------------------------------------------------------*\
  Function name: virtual Draw
  Member of:     public ThruputView
  Defined in:    ThruputView.cpp
  Arguments:     BRect a_update_rect - the rect to be updated.
  Returns:       none
  Throws:        none
  Description: Derived hook function.
\*--------------------------------------------------------------------*/
		
		virtual void Draw(BRect a_update_rect);
		
/*--------------------------------------------------------------------*\
  Function name: virtual MessageReceived
  Member of:     public ThruputView
  Defined in:    ThruputView.cpp
  Arguments:     BMessage * const a_msg - the message received.
  Returns:       none
  Throws:        none
  Description: Derived hook function.
\*--------------------------------------------------------------------*/
		
		virtual void MessageReceived(BMessage * const a_msg);
		
/*--------------------------------------------------------------------*\
  Function name: virtual Pulse
  Member of:     public ThruputView
  Defined in:    ThruputView.cpp
  Arguments:     none
  Returns:       none
  Throws:        none
  Description: Derived hook function.
\*--------------------------------------------------------------------*/
		
		virtual void Pulse(void);
		
/*--------------------------------------------------------------------*\
  Function name: SelectedDevice
  Member of:     public ThruputView
  Defined in:    ThruputView.cpp
  Arguments:     none
  Returns:       const char * - the selected device on success, null
                     on failure.
  Throws:        none
  Description: Function to return the selected device (if any) of the
      view.
\*--------------------------------------------------------------------*/
		
		const char *SelectedDevice(void);
		
/*--------------------------------------------------------------------*\
  Function name: SelectedScale
  Member of:     public ThruputView
  Defined in:    ThruputView.cpp
  Arguments:     none
  Returns:       size_t - the selected scale.
  Throws:        none
  Description: Function to return the selected scale of the view.
\*--------------------------------------------------------------------*/
		
		size_t SelectedScale(void);
		
/*--------------------------------------------------------------------*\
  Function name: inline Status const
  Member of:     public ThruputView
  Arguments:     none
  Returns:       status_t - B_NO_ERROR if the object is valid, another
                     error code if not (see below).
  Throws:        none
  Description: Function to check if the object is valid. This function
      must be called after creating the object to insure that its
      instantiation was successful. Possible return values are as
      follows:
      
      B_NO_ERROR - the object was created successfully.
      B_NO_MEMORY - on construction, there was not enough memory
          available to create the object.
\*--------------------------------------------------------------------*/
		
		inline int Status(void) const
		{
			return m_status;
		}
	
	private:
	
		// Private static const data members
		static const float mk_border;
		static const float mk_hght_spc;
		static const float mk_bar_width;
		static const float mk_field_width;
		static const char * const mk_devs;
		static const char * const mk_bps;
		static const rgb_color mk_high;
		static const rgb_color mk_light;
		static const rgb_color mk_dark;
		
		// Private data members
		status_t m_status;
		port_id m_port;
		BMenu *m_devs_menu;
		BMenuField *m_devs;
		BMenu *m_bps_menu;
		BMenuField *m_bps;
		BStatusBar *m_thrpt_read;
		BStatusBar *m_thrpt_write;
};


#endif    // THRUPUT_VIEW_H
